@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 Regents of The University of Michigan.
+ * Copyright (c) 2005 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
  */
 
@@ -15,8 +15,13 @@
 @interface SFTPTableView : NSTableView
 {
 @private
-    int		rightClickedRow;
-    NSTimer     *springLoadedTimer;
+    int		    rightClickedRow;
+    int		    _sftpDragPhase;
+    NSTimer	    *springLoadedTimer;
+    NSImage	    *_sftpOriginalDragImage;
+    NSArray	    *_sftpOriginalPboardTypes;
+    NSMutableArray  *_sftpOriginalPboardPlists;
+    BOOL	    _sftpDragPromisedFiles;
 }
 
 - ( void )keyDown: ( NSEvent * )theEvent;
@@ -26,6 +31,9 @@
 
 - ( void )addTableColumnWithIdentifier: ( id )identifier
             columnTitle: ( NSString * )title width: ( float )width;
+	    
+- ( BOOL )dragPromisedFiles;
+- ( void )setDragPromisedFiles: ( BOOL )promised;
 
 @end
 
@@ -44,4 +52,11 @@ float		WidthForColumnWithIdentifier( NSString *identifier );
             column: ( int )column
             row: ( int )row;
 
+@end
+
+/* additional dataSource methods */
+@interface NSObject(SFTPTableViewDataSource)
+- ( NSArray * )promisedNamesFromPlists: ( id )plist;
+- ( BOOL )handleDroppedPromisedFiles: ( NSArray * )promisedFiles
+	    destination: ( NSString * )dropDestination;
 @end
\ No newline at end of file
